(v1.4.4)=
### 1.4.4 {small}`2019-07-20`

#### New functionality

- {mod}`scanpy.get` adds helper functions for extracting data in convenient formats {pr}`619` {smaller}`I Virshup`

#### Bug fixes

- Stopped deprecations warnings from AnnData `0.6.22` {smaller}`I Virshup`

#### Code design

- {func}`~scanpy.pp.normalize_total` gains param `exclude_highly_expressed`, and `fraction` is renamed to `max_fraction` with better docs {smaller}`A Wolf`
